Iowa Judicial Branch
Description: State of Iowa Official Judicial Branch Website

About the Courts
| Supreme Court
| Supreme Court Justices
| Supreme Court Opinions
| Email Notification Service
| Recent Opinions
| Opinions Expected
| Opinions Archive
| Further Review Orders
| Orders
| Oral Argument Schedule
| 2013-14 Court Calendar
| 2014-15 Court Calendar
| Oral Argument Videos
| State of the Judiciary
| Request for Speaker
| Court of Appeals
| District Courts
| Juvenile Court
| Specialty Courts
| Small Claims Courts
| Jury Service
| Directories
| Advisory Committees
| You are here: Home » About the Courts » Supreme Court » Supreme Court Opinions |
Printable Version |
Iowa Supreme Court Opinions
July 18, 2014
Notice: The opinions posted on this site are slip opinions only. Under the Rules of Appellate Procedure a party has a limited number of days to request a rehearing after the filing of an opinion. Also, all slip opinions are subject to modification or correction by the court. Therefore, opinions on this site are not to be considered the final decisions of the court. The official published opinions of the Iowa Supreme Court are those published in the North Western Reporter published by West Group.
Opinions released before April 2006 and available in the archives are posted in Word format. Opinions released after April 2006 are posted to the website in PDF (Portable Document Format). Note: To open a PDF you must have the free Acrobat Reader installed. PDF format preserves the original appearance of a document without requiring you to possess the software that created that document. For more information about PDF read: Using the Adobe Reader.
For your convenience, the Judicial Branch offers a free e-mail notification service for Supreme Court opinions, Court of Appeals opinions, press releases and orders. To subscribe, click here.
NOTE: Copies of these opinions may be obtained from the Clerk of the Supreme Court, Judicial Branch Building, 1111 East Court Avenue, Des Moines, IA 50319, for a fee of fifty cents per page.
No. 11–1020
STATE OF IOWA vs. GABRIEL DETRACE TAYLOR
No. 11–1339
STATE OF IOWA vs. ANDRE JEROME LYLE JR.
No. 12–0913
LINDA PIPPEN, et al., On Behalf of Themselves and All Others Similarly Situated vs. THE STATE OF IOWA, et al., and ALL OTHER AGENCIES SIMILARLY SITUATED IN USING THE HIRING AND PROMOTION OF ADMINISTRATIVE SERVICES
No. 12–1150
STATE OF IOWA vs. JUSTIN DEAN SHORT
No. 12–1182
DENNIS L. SMITH vs. IOWA STATE UNIVERSITY OF SCIENCE AND TECHNOLOGY and STATE OF IOWA
No. 12–1899
STATE OF IOWA vs. PATRICK EDOUARD

| return to top

Directories | ADA Access | Site Tools | Site Map | Privacy Policy | Contact Us Copyright © 2014 Iowa Judicial Branch